Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Broker ¶
type Broker struct {
// contains filtered or unexported fields
}
Broker implements a non-blocking fan-out pub/sub for query events. Slow subscribers silently drop events to avoid blocking the publisher.
func (*Broker) Publish ¶
Publish sends an event to all subscribers. If a subscriber's buffer is full, the event is dropped for that subscriber.
func (*Broker) Subscribe ¶
Subscribe returns a channel that receives published events and an unsubscribe function. The unsubscribe function is idempotent.
func (*Broker) SubscriberCount ¶
Click to show internal directories.
Click to hide internal directories.